package com.cweb.controller.jd;

import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;

import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.jd.JdPostService;
import com.hfkj.jd.JdService;
import com.hfkj.model.ResponseData;

import com.jd.open.api.sdk.response.vopdz.VopAddressConvertFourAreaByDetailStrResponse;
import com.jd.open.api.sdk.response.vopdz.VopAddressQueryJdAreaIdListResponse;
import com.jd.open.api.sdk.response.vopdz.VopAddressVerifyAreaFourIdOpenReqResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;


@Controller
@RequestMapping(value="/jd")
@Api(value="京东")
public class JdController {

    Logger log = LoggerFactory.getLogger(JdController.class);

    @Resource
    private JdService jdService;

    @RequestMapping(value="/queryJdAreaIdList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询四级地址ID列表")
    public ResponseData queryJdAreaIdList(@RequestParam(value = "areaLevel", required = false) Integer areaLevel,
                                        @RequestParam(value = "areaId", required = false) Long areaId
    ) {
        try {

            VopAddressQueryJdAreaIdListResponse response = JdPostService.queryJdAreaIdList(jdService.getToken() , areaLevel , areaId);

            if (!response.getOpenRpcResult().getSuccess()) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未查询到任何信息！");
            }

            return ResponseMsgUtil.success(response.getOpenRpcResult().getResult().getAreaInfoList());

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/verifyAreaFourIdOpenReq",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "验证四级地址ID有效性")
    public ResponseData verifyAreaFourIdOpenReq(@RequestParam(value = "provinceId", required = false) Long provinceId,
                                          @RequestParam(value = "cityId", required = false) Long cityId,
                                          @RequestParam(value = "countyId", required = false) Long countyId,
                                          @RequestParam(value = "townId", required = false) Long townId
    ) {
        try {

            VopAddressVerifyAreaFourIdOpenReqResponse response = JdPostService.verifyAreaFourIdOpenReq(jdService.getToken() , provinceId , cityId , countyId , townId);

            return ResponseMsgUtil.success(response.getOpenRpcResult().getSuccess());

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/convertFourAreaByDetailStr",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "地址详情转换京东地址编码")
    public ResponseData convertFourAreaByDetailStr(@RequestParam(value = "address", required = false) String address
    ) {
        try {

            VopAddressConvertFourAreaByDetailStrResponse response = JdPostService.convertFourAreaByDetailStr(jdService.getToken() , address);

            return ResponseMsgUtil.success(response.getOpenRpcResult().getResult());

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
