package com.hfkj.jd.Impl;

import com.hfkj.common.utils.RedisUtil;
import com.hfkj.entity.*;
import com.hfkj.jd.JdPostService;
import com.hfkj.jd.JdService;
import com.hfkj.service.BsMerService;
import com.hfkj.service.BsProductConfigService;
import com.hfkj.service.goods.*;
import com.hfkj.sysenum.order.OrderChildProductTypeEnum;
import com.jd.open.api.sdk.domain.vopsp.SkuInfoGoodsProvider.response.getSellPrice.GetSellPriceGoodsResp;
import com.jd.open.api.sdk.domain.vopsp.SkuInfoGoodsProvider.response.getSellPrice.OpenRpcResult;
import com.jd.open.api.sdk.domain.vopsp.SkuInfoGoodsProvider.response.getSkuDetailInfo.GetSkuPoolInfoGoodsResp;
import com.jd.open.api.sdk.domain.vopsp.SkuInfoGoodsProvider.response.getSkuImageList.GetSkuImageGoodsResp;
import com.jd.open.api.sdk.domain.vopsp.SkuInfoGoodsProvider.response.getSkuImageList.SkuImageItemGoodsResp;
import com.jd.open.api.sdk.domain.vopsp.SkuPoolGoodsProvider.response.getSkuPoolInfo.GetSkuPoolInfoItemGoodsResp;
import com.jd.open.api.sdk.response.vopsp.VopGoodsGetSkuDetailInfoResponse;
import com.jd.open.api.sdk.response.vopsp.VopGoodsGetSkuImageListResponse;
import com.jd.open.api.sdk.response.vopsp.VopGoodsGetSkuPoolInfoResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@Service("jdService")
public class JdServiceImpl implements JdService {

    @Autowired
    private RedisUtil redisUtil;

    @Resource
    private BsMerService bsMerService;

    @Resource
    private GoodsTypeService goodsTypeService;

    @Resource
    private GoodsBrandService goodsBrandService;

    @Resource
    private BsProductConfigService productConfigService;

    @Resource
    private GoodsMsgService goodsMsgService;

    @Resource
    private GoodsSpecsService goodsSpecsService;

    @Override
    public String getToken() throws Exception {
        Object token = redisUtil.get("access_token");

        if (token == null) {
            // 请求回调 会在回调存入参数
            JdPostService.getAccessToken();
            getToken();
        }

        return token.toString();
    }

    @Override
    public void getGoodsJd() throws Exception {
        // 获取京东商品池
        VopGoodsGetSkuPoolInfoResponse sku = JdPostService.getSkuPoolInfo(getToken());
        // 获取sku列表
        List<GetSkuPoolInfoItemGoodsResp> skuList = sku.getOpenRpcResult().getResult().getSkuPoolList();

        // 初始化商品信息
        GoodsMsg goodsMsg;
        // 初始化商品规格
        GoodsSpecs goodsSpecs;

        BsMer bsMer = bsMerService.getDetail("166241009282");
        // 查询分类
        List<GoodsType> goodsType = goodsTypeService.getList(new HashMap<>());
        List<GoodsBrand> brands = goodsBrandService.getList(new HashMap<>());
        Map<String, Object> goodsMap = new HashMap<>();
        goodsMap.put("type", 3);
        List<GoodsMsg> goodsMsgs = goodsMsgService.getList(goodsMap);
        List<GoodsSpecs> goodsSpecsList = goodsSpecsService.getList(new HashMap<>());
        BsProductConfig productConfig = productConfigService.queryDetail(OrderChildProductTypeEnum.type6.getCode());

        for (GetSkuPoolInfoItemGoodsResp skuPoolInfoItemGoodsResp : skuList) {

            // 根据sku查询商品
            List<Long> skuIdList = JdPostService.querySkuByPage(getToken(), skuPoolInfoItemGoodsResp.getBizPoolId(), 0).getOpenRpcResult().getResult().getSkus();
            for (Long aLong : skuIdList) {

                // 根据skuId 查询商品详情
                VopGoodsGetSkuDetailInfoResponse skuDetail = JdPostService.getSkuDetailInfo(getToken(), aLong);
                GetSkuPoolInfoGoodsResp detail = skuDetail.getOpenRpcResult().getResult();
                if (detail != null) {
                    // 根据skuId 查询商品售价
                    OpenRpcResult priceResponse = JdPostService.getSellPrice(getToken(), String.valueOf(aLong)).getOpenRpcResult();
                    if (priceResponse.getSuccess()) {
                        GetSellPriceGoodsResp price = priceResponse.getResult().get(0);
                        // 根据skuId 查询商品图片

                        com.jd.open.api.sdk.domain.vopsp.SkuInfoGoodsProvider.response.getSkuImageList.OpenRpcResult imageListResponse = JdPostService.getSkuImageList(getToken(), String.valueOf(aLong)).getOpenRpcResult();
                        if (imageListResponse.getSuccess()) {
                            GetSkuImageGoodsResp img = imageListResponse.getResult().get(0);
                            // 查询分类
                            String[] categoryS = detail.getCategory().split(";");

                            // 查询一级分类
                            String category1 = JdPostService.getCategoryInfoList(getToken(), categoryS[0]).getOpenRpcResult().getResult().get(0).getCategoryName();
                            // 查询二级分类
                            String category2 = JdPostService.getCategoryInfoList(getToken(), categoryS[1]).getOpenRpcResult().getResult().get(0).getCategoryName();

                            GoodsType goodsType1 = goodsType.stream().filter(s -> s.getTitle().equals(category1)).findFirst().orElse(null);
                            GoodsType goodsType2 = goodsType.stream().filter(s -> s.getTitle().equals(category2)).findFirst().orElse(null);

                            // 如果goodsType1为null，则创建一个新的GoodsType对象
                            if (goodsType1 == null) {
                                goodsType1 = new GoodsType();
                                // 设置title为category1
                                goodsType1.setTitle(category1);
                                // 设置status为1
                                goodsType1.setStatus(1);
                                goodsType1.setBusinessType(1);
                                // 设置sort为8
                                goodsType1.setSort(8);
                                // 设置createTime为当前时间
                                goodsType1.setCreateTime(new Date());
                                // 设置updateTime为当前时间
                                goodsType1.setUpdateTime(new Date());
                                // 调用goodsTypeService的create方法，将goodsType1对象保存到数据库中
                                goodsTypeService.create(goodsType1);
                                goodsType.add(goodsType1);
                            }
                            if (goodsType2 == null) {
                                goodsType2 = new GoodsType();
                                // 设置title为category2
                                goodsType2.setTitle(category2);
                                goodsType2.setParentId(goodsType1.getId());
                                // 设置status为1
                                goodsType2.setStatus(1);
                                // 设置businessType为1
                                goodsType2.setBusinessType(1);
                                // 设置sort为8
                                goodsType2.setSort(1);
                                // 设置createTime为当前时间
                                goodsType2.setCreateTime(new Date());
                                // 设置updateTime为当前时间
                                goodsType2.setUpdateTime(new Date());
                                // 调用goodsTypeService的create方法，将goodsType2对象保存到数据库中
                                goodsTypeService.create(goodsType2);
                                goodsType.add(goodsType2);
                            } else {
                                goodsType2.setParentId(goodsType1.getId());
                                goodsType2.setUpdateTime(new Date());
                                goodsTypeService.update(goodsType2);
                            }
                            // 从brands中筛选出title等于detail.getBrandName()的元素，并返回第一个元素，如果没有找到则返回null
                            GoodsBrand goodsBrand = brands.stream().filter(s -> s.getTitle().equals(detail.getBrandName())).findFirst().orElse(null);
                            // 如果goodsBrand为null，则创建一个新的GoodsBrand对象
                            if (goodsBrand == null) {
                                goodsBrand = new GoodsBrand();
                                // 设置title为detail.getBrandName()
                                goodsBrand.setTitle(detail.getBrandName());
                                // 设置status为1
                                goodsBrand.setStatus(1);
                                // 设置createTime为当前时间
                                goodsBrand.setCreateTime(new Date());
                                // 设置updateTime为当前时间
                                goodsBrand.setUpdateTime(new Date());
                                // 调用goodsBrandService的create方法，将goodsBrand对象保存到数据库中
                                goodsBrandService.create(goodsBrand);
                                brands.add(goodsBrand);
                            }

                            // 创建一个GoodsMsg对象
                            goodsMsg = new GoodsMsg();
                            // 设置更新时间为当前时间
                            goodsMsg.setUpdateTime(new Date());
                            // 设置商家ID为bsMer的ID
                            goodsMsg.setMerId(bsMer.getId());
                            // 设置商家名称为bsMer的名称
                            goodsMsg.setMerName(bsMer.getMerName());
                            // 设置商品名称为detail.getGoodsName()
                            goodsMsg.setTitle(detail.getSkuName());
                            // 设置商品类型为3
                            goodsMsg.setType(1);
                            // 设置商品状态为1
                            goodsMsg.setStatus(1);
                            // 设置商品子类型为1
                            goodsMsg.setChildType(1);
                            // 设置商品品牌ID
                            goodsMsg.setGoodsBrand(goodsBrand.getId());
                            // 设置商品品牌名称
                            goodsMsg.setGoodsBrandName(goodsBrand.getTitle());
                            // 设置商品类型ID
                            goodsMsg.setGoodsType(goodsType2.getId());
                            // 设置商品类型名称
                            goodsMsg.setGoodsTypeName(goodsType2.getTitle());
                            // 设置商品类型父级ID
                            goodsMsg.setGoodsTypeParent(goodsType1.getId());
                            // 设置商品类型父级名称
                            goodsMsg.setGoodsTypeParentName(goodsType1.getTitle());
                            goodsMsg.setThirdId(aLong.toString());
                            StringBuilder imgS = new StringBuilder();
                            // 遍历商品图片列表
                            for (SkuImageItemGoodsResp skuImage : img.getSkuImageList()) {
                                // 如果图片是主图
                                if (skuImage.getIsPrimary() == 1) {
                                    // 设置主图
                                    goodsMsg.setListImg("https://img13.360buyimg.com/n1/" + skuImage.getShortPath());
                                }
                                // 如果图片不是主图
                                if (skuImage.getIsPrimary() == 0) {

                                    imgS.append("https://img13.360buyimg.com/n1/").append(skuImage.getShortPath()).append(",");

                                }
                            }

                            if (imgS.length() > 0) {
                                imgS.deleteCharAt(imgS.length() - 1);
                            }

                            // 设置轮播图
                            goodsMsg.setBannerImg(String.valueOf(imgS));
                            // 设置详情图
                            goodsMsg.setDetailImg(String.valueOf(imgS));
                            GoodsMsg msg = goodsMsgs.stream().filter(s -> s.getThirdId().equals(aLong.toString())).findFirst().orElse(null);

                            if (msg != null) {
                                goodsMsg.setId(msg.getId());
                                // 更新商品信息
                                goodsMsgService.update(goodsMsg);
                            } else {
                                // 设置销售数量为0
                                goodsMsg.setSaleNum(0);
                                goodsMsg.setCreateTime(new Date());
                                // 创建商品信息
                                goodsMsgService.create(goodsMsg);

                            }

                            // 创建商品规格
                            goodsSpecs = new GoodsSpecs();
                            // 设置商品ID
                            goodsSpecs.setGoodsId(goodsMsg.getId());
                            // 设置商品名称
                            goodsSpecs.setName(detail.getSpuName());
                            // 设置更新时间
                            goodsSpecs.setUpdateTime(new Date());
                            // 设置采购限制
                            goodsSpecs.setPurLimit(99999);
                            // 设置状态
                            goodsSpecs.setStatus(1);
                            goodsSpecs.setThirdId(aLong.toString());
                            // 设置库存
                            goodsSpecs.setStock(10000);
                            BigDecimal profitPrice = price.getSalePrice().multiply(productConfig.getDiscount().divide(new BigDecimal(100) , 2, RoundingMode.HALF_UP));
                            // 设置销售价格
                            goodsSpecs.setSalePrice(profitPrice.add(price.getSalePrice()));
                            // 设置原价
                            goodsSpecs.setOriginalPrice(price.getMarketPrice());
                            // 设置展示图片
                            goodsSpecs.setShowImg(goodsMsg.getListImg());

                            GoodsSpecs specs = goodsSpecsList.stream().filter(s -> s.getThirdId().equals(aLong.toString())).findFirst().orElse(null);

                            if (specs != null) {
                                goodsSpecs.setId(specs.getId());
                                // 更新商品规格
                                goodsSpecsService.update(goodsSpecs);
                            } else {
                                // 设置创建时间
                                goodsSpecs.setCreateTime(new Date());
                                // 创建商品规格
                                goodsSpecsService.create(goodsSpecs);
                            }
                        }

                    }
                }


            }
        }
    }
}
